# sourmash_plugin_venn: generate a simple Venn diagram for two sourmash sketches

Generate Venn diagrams showing overlaps between two
[sourmash sketches](https://sourmash.readthedocs.io/) of DNA or
protein sequences:

![simple Venn diagram](doc/simple.png)

## Execution

```
sourmash scripts venn a.sig b.sig -o a-v-b.png
```

## Installation

```
pip install sourmash_plugin_venn
```
